changeset 6570:52ecfeddf864

Changed the -pass option to -passwd to avoid clash with mencoder option.
author bertrand
date Tue, 25 Jun 2002 23:56:33 +0000
parents 39a7509868de
children fdf45e8420d0
files libmpdemux/network.c
diffstat 1 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/libmpdemux/network.c	Tue Jun 25 23:33:46 2002 +0000
+++ b/libmpdemux/network.c	Tue Jun 25 23:56:33 2002 +0000
@@ -32,7 +32,7 @@
 extern int verbose;
 extern m_config_t *mconfig;
 
 /* Variables for the command line option -user & -pass */
 char *network_username;
 char *network_password;
 
@@ -344,7 +344,7 @@
 	int ret;
 	if( *auth_retry==1 ) {
 		mp_msg(MSGT_NETWORK,MSGL_ERR,"Authentication failed\n");
-		mp_msg(MSGT_NETWORK,MSGL_ERR,"Please use the option -user and -pass to provide your username/password for a list of URLs,\n");
+		mp_msg(MSGT_NETWORK,MSGL_ERR,"Please use the option -user and -passwd to provide your username/password for a list of URLs,\n");
 		mp_msg(MSGT_NETWORK,MSGL_ERR,"or form an URL like: http://username:password@hostname/file\n");
 		return -1;
 	}
@@ -381,14 +381,14 @@
 		strcpy(url->username, username);
 	} else {
 		mp_msg(MSGT_NETWORK,MSGL_ERR,"Unable to read the username\n");
-		mp_msg(MSGT_NETWORK,MSGL_ERR,"Please use the option -user and -pass to provide your username/password for a list of URLs,\n");
+		mp_msg(MSGT_NETWORK,MSGL_ERR,"Please use the option -user and -passwd to provide your username/password for a list of URLs,\n");
 		mp_msg(MSGT_NETWORK,MSGL_ERR,"or form an URL like: http://username:password@hostname/file\n");
 		return -1;
 	}
-	ret = m_config_is_option_set(mconfig,"pass");
+	ret = m_config_is_option_set(mconfig,"passwd");
 	if( ret==1 ) {
 		char *password;
-		password = *((char**)m_config_get_option_ptr(mconfig, "pass"));
+		password = *((char**)m_config_get_option_ptr(mconfig, "passwd"));
 		if( password==NULL ) return -1;
 		url->password = (char*)malloc(strlen(password)+1);
 		if( url->password==NULL ) {
@@ -32,7 +32,7 @@
 extern m_config_t *mconfig;
 
-/* Variables for the command line option -user & -pass */
+/* Variables for the command line option -user & -passwd */
 char *network_username;
 char *network_password;